Index — intake_elasticsearch 0.0.1 documentation

# Index

E | O | T

## E

ElasticSearchSeqSource (class in intake_elasticsearch.elasticsearch_seq) ElasticSearchTableSource (class in intake_elasticsearch.elasticsearch_table) | ESSeqPlugin (class in intake_elasticsearch) ESTablePlugin (class in intake_elasticsearch)

## O

open() (intake_elasticsearch.ESSeqPlugin method)

## T

to_dask() (intake_elasticsearch.elasticsearch_table.ElasticSearchTableSource method)